@@ -56,7 +56,13 @@ class PhppearCliTest extends PHPUnit_Framework_TestCase {
     }
 
     public function testPhppearDescription() {
-        $this->expectOutputString('<Some random notes>');
+        $this->expectOutputString('<Some random notes>
+    This is a paragraph.
+
+    Those are bullets:
+    * Number one
+    * Number two
+ ');
         chdir('testsuite/data/pearpkg1');
         $this->_cli->parseArgs(Array('phppear', 'description'));
     }
@@ -93,11 +99,12 @@ recommend:pear-pecl.php.net/mysqli
     }
 
     public function testPhppearSubstvars() {
-        $this->expectOutputString('phppear:Debian-Depends=php5-common (>= 5.2.1), php-alpha (>= 1.0~a), php-alpha (<= 2.0~alpha3), php-beta (>= 1.0~b2), php-beta (<< 2.0~beta4), php-rc (>= 1.0~RC2), php-rc (<= 2.0~RC5), php-horde-alarm (>= 2.2.0), php-horde-alarm (<< 3.0.0~alpha1), phpunit (>= 1.1), phpunit (<= 1.9)
-phppear:Debian-Recommends=php5-mysql
+        $this->expectOutputString('phppear:Debian-Depends=php-common, php-alpha (>= 1.0~a), php-alpha (<= 2.0~alpha3), php-beta (>= 1.0~b2), php-beta (<< 2.0~beta4), php-rc (>= 1.0~RC2), php-rc (<= 2.0~RC5), php-horde-alarm (>= 2.2.0), php-horde-alarm (<< 3.0.0~alpha1), phpunit (>= 1.1), phpunit (<= 1.9)
+phppear:Debian-Recommends=php-mysql
+phppear:Debian-Suggests=
 phppear:Debian-Breaks=
 phppear:summary=this is a wrapper package for installing dependencies for MyProject
-phppear:description=<Some random notes>
+phppear:description=<Some random notes>${Newline}This is a paragraph.${Newline}${Newline}Those are bullets:${Newline} * Number one${Newline} * Number two${Newline}
 phppear:channel=pear.php.net
 ');
         chdir('testsuite/data/pearpkg1');
